@@ -9,7 +9,7 @@ from django.conf import settings
 from decorator import commit_on_success
 
 __all__ = ('record', 'error_record', 'Journal')
-__version__ = '1.10.0'
+__version__ = '1.12.0'
 
 def unicode_truncate(s, length, encoding='utf-8'):
     '''Truncate an unicode string so that its UTF-8 encoding is less than
@@ -40,9 +40,9 @@ def record(tag, template, using=None, **kwargs):
     try:
         logger = logging.getLogger('django.journal.%s' % tag)
         if tag.name == 'error':
-            logger.error(message)
+            logger.error(message.encode('utf8'))
         else:
-            logger.info(message)
+            logger.info(message.encode('utf8'))
     except:
         try:
             logging.getLogger('django.journal').exception('Unable to log msg')
