@@ -101,9 +101,12 @@ class JournalAdmin(admin.ModelAdmin):
         '''Search and return any associated stringdata whose tag is "ip"'''
         for stringdata in entry.stringdata_set.all():
             if stringdata.tag.name == 'ip':
-                return stringdata.content
+                return u'<a href="?stringdata__tag__id={tag_id}&' \
+                       u'stringdata__content={ip}">{ip}</a>'.format(
+                        tag_id=stringdata.tag.id, ip=stringdata.content)
         return _('None')
     ip.short_description = _('IP')
+    ip.allow_tags = True
 
     def user(self, entry):
         '''Search and return any associated objectdata whose tag is "user"'''
@@ -116,12 +119,20 @@ class JournalAdmin(admin.ModelAdmin):
     user.short_description = _('User')
 
     def object_filter_link(self, objectdata):
+        if objectdata.content_object is not None:
+            caption = unicode(objectdata.content_object)
+        else:
+            caption = _(u'<deleted {content_type} {object_id}>').format(
+                    content_type=objectdata.content_type,
+                    object_id=objectdata.object_id)
         return u'<a href="?objectdata__content_type={0}&objectdata__object_id={1}">{2}</a>'.format(
                     objectdata.content_type_id,
                     objectdata.object_id,
-                    objectdata.content_object)
+                    caption)
 
     def object_link(self, obj_data):
+        if obj_data.content_object is None:
+            return u''
         url = u'{0}:{1}_{2}_change'.format(self.admin_site.name,
                 obj_data.content_type.app_label,
                 obj_data.content_type.model)
